@@ -220,7 +220,8 @@ impl GetDatasetsColumnUsage for MarkSpec {
             // the subset datasets are used.
             if let Some(facet) = self.from.as_ref().and_then(|from| from.facet.clone()) {
                 let facet_data_var = Variable::new_data(&facet.data);
-                if let Ok(resolved) = task_scope.resolve_scope(&facet_data_var, usage_scope) {
+                let parent_scope = &usage_scope[0..usage_scope.len() - 1];
+                if let Ok(resolved) = task_scope.resolve_scope(&facet_data_var, parent_scope) {
                     let scoped_facet_data_var = (resolved.var, resolved.scope);
                     usage = usage.with_unknown_usage(&scoped_facet_data_var);
                 }
@@ -700,8 +701,8 @@ impl<'a> MutChartVisitor for InsertProjectionVisitor<'a> {
                 // so we can append a projection transform to limit the columns that are produced
                 // Note: empty strings here seem to break vega, filter them out
                 let proj_fields: Vec<_> = sorted(columns)
+                    .filter(|&f| !f.is_empty())
                     .cloned()
-                    .filter(|f| !f.is_empty())
                     .map(|f| escape_field(&f))
                     .collect();
 
