@@ -141,8 +141,9 @@ impl SortOrderOrList {
 }
 
 /// Helper struct that will not drop null values on round trip (de)serialization
-#[derive(Debug, Clone, PartialEq, Eq)]
+#[derive(Debug, Clone, PartialEq, Eq, Default)]
 pub enum MissingNullOrValue {
+    #[default]
     Missing,
     Null,
     Value(serde_json::Value),
@@ -162,12 +163,6 @@ impl MissingNullOrValue {
     }
 }
 
-impl Default for MissingNullOrValue {
-    fn default() -> Self {
-        MissingNullOrValue::Missing
-    }
-}
-
 impl From<Option<serde_json::Value>> for MissingNullOrValue {
     fn from(opt: Option<serde_json::Value>) -> MissingNullOrValue {
         match opt {
