@@ -2,7 +2,7 @@ use std::sync::Arc;
 use vegafusion_common::arrow::array::{Array, ArrayRef, UInt32Array};
 use vegafusion_common::arrow::compute::sort_to_indices;
 use vegafusion_common::arrow::datatypes::{DataType, Field, FieldRef};
-use vegafusion_common::data::scalar::ScalarValueHelpers;
+use vegafusion_common::data::scalar::{ArrayRefHelpers, ScalarValueHelpers};
 use vegafusion_common::datafusion_common::{DataFusionError, ScalarValue};
 use vegafusion_common::datafusion_expr::{create_udaf, Accumulator, AggregateUDF, Volatility};
 
@@ -18,9 +18,9 @@ pub(crate) struct PercentileContAccumulator {
 }
 
 impl Accumulator for PercentileContAccumulator {
-    fn state(&self) -> Result<Vec<ScalarValue>, DataFusionError> {
-        let state = ScalarValue::new_list(Some(self.all_values.clone()), self.data_type.clone());
-        Ok(vec![state])
+    fn state(&mut self) -> Result<Vec<ScalarValue>, DataFusionError> {
+        let state = ScalarValue::new_list(self.all_values.as_slice(), &self.data_type);
+        Ok(vec![ScalarValue::List(state)])
     }
 
     fn update_batch(&mut self, values: &[ArrayRef]) -> Result<(), DataFusionError> {
@@ -43,14 +43,13 @@ impl Accumulator for PercentileContAccumulator {
         assert!(matches!(array.data_type(), DataType::List(_)));
         for index in 0..array.len() {
             match ScalarValue::try_from_array(array, index)? {
-                ScalarValue::List(Some(values), _) => {
-                    for scalar in values {
+                ScalarValue::List(array) => {
+                    for scalar in array.value(0).to_scalar_vec()? {
                         if !scalar_is_non_finite(&scalar) {
                             self.all_values.push(scalar);
                         }
                     }
                 }
-                ScalarValue::List(None, _) => {} // skip empty state
                 v => {
                     return Err(DataFusionError::Internal(format!(
                         "unexpected state in percentile_cont. Expected DataType::List, got {v:?}"
@@ -61,7 +60,7 @@ impl Accumulator for PercentileContAccumulator {
         Ok(())
     }
 
-    fn evaluate(&self) -> Result<ScalarValue, DataFusionError> {
+    fn evaluate(&mut self) -> Result<ScalarValue, DataFusionError> {
         if !self.all_values.iter().any(|v| !v.is_null()) {
             return ScalarValue::try_from(&self.data_type);
         }
