@@ -1,5 +1,5 @@
 use crate::task_graph::timezone::RuntimeTzConfig;
-use datafusion_expr::{expr, lit, Expr, ExprSchemable};
+use datafusion_expr::{expr, lit, Expr, ExprSchemable, ScalarFunctionDefinition};
 use std::sync::Arc;
 use vegafusion_common::arrow::datatypes::DataType;
 use vegafusion_common::datafusion_common::{DFSchema, ScalarValue};
@@ -41,23 +41,25 @@ pub fn time_format_fn(
         // Special case for ISO-8601 format with milliseconds. The UTC_TIMESTAMP_TO_STR_UDF
         // is compatible with more SQL dialects, so we want to use it if possible
         let udf_args = vec![timestamptz_expr, lit(&format_tz_str)];
-        Ok(Expr::ScalarUDF(expr::ScalarUDF {
-            fun: Arc::new((*UTC_TIMESTAMP_TO_STR_UDF).clone()),
+        Ok(Expr::ScalarFunction(expr::ScalarFunction {
+            func_def: ScalarFunctionDefinition::UDF(Arc::new((*UTC_TIMESTAMP_TO_STR_UDF).clone())),
             args: udf_args,
         }))
     } else {
         // General case
         if format_tz_str.to_ascii_lowercase() != "utc" {
-            timestamptz_expr = Expr::ScalarUDF(expr::ScalarUDF {
-                fun: Arc::new((*FROM_UTC_TIMESTAMP_UDF).clone()),
+            timestamptz_expr = Expr::ScalarFunction(expr::ScalarFunction {
+                func_def: ScalarFunctionDefinition::UDF(Arc::new(
+                    (*FROM_UTC_TIMESTAMP_UDF).clone(),
+                )),
                 args: vec![timestamptz_expr, lit(format_tz_str)],
             })
         }
 
         let udf_args = vec![timestamptz_expr, lit(format_str)];
 
-        Ok(Expr::ScalarUDF(expr::ScalarUDF {
-            fun: Arc::new((*FORMAT_TIMESTAMP_UDF).clone()),
+        Ok(Expr::ScalarFunction(expr::ScalarFunction {
+            func_def: ScalarFunctionDefinition::UDF(Arc::new((*FORMAT_TIMESTAMP_UDF).clone())),
             args: udf_args,
         }))
     }
@@ -76,15 +78,15 @@ pub fn utc_format_fn(
         // Special case for ISO-8601 format with milliseconds. The UTC_TIMESTAMP_TO_STR_UDF
         // is compatible with more SQL dialects, so we want to use it if possible
         let udf_args = vec![timestamptz_expr, lit("UTC")];
-        Ok(Expr::ScalarUDF(expr::ScalarUDF {
-            fun: Arc::new((*UTC_TIMESTAMP_TO_STR_UDF).clone()),
+        Ok(Expr::ScalarFunction(expr::ScalarFunction {
+            func_def: ScalarFunctionDefinition::UDF(Arc::new((*UTC_TIMESTAMP_TO_STR_UDF).clone())),
             args: udf_args,
         }))
     } else {
         // General case
         let udf_args = vec![timestamptz_expr, lit(format_str)];
-        Ok(Expr::ScalarUDF(expr::ScalarUDF {
-            fun: Arc::new((*FORMAT_TIMESTAMP_UDF).clone()),
+        Ok(Expr::ScalarFunction(expr::ScalarFunction {
+            func_def: ScalarFunctionDefinition::UDF(Arc::new((*FORMAT_TIMESTAMP_UDF).clone())),
             args: udf_args,
         }))
     }
@@ -101,14 +103,16 @@ fn to_timestamptz_expr(arg: &Expr, schema: &DFSchema, default_input_tz: &str) ->
             data_type: DataType::Timestamp(TimeUnit::Millisecond, None),
         }),
         DataType::Timestamp(_, _) => arg.clone(),
-        DataType::Utf8 => Expr::ScalarUDF(expr::ScalarUDF {
-            fun: Arc::new((*STR_TO_UTC_TIMESTAMP_UDF).clone()),
+        DataType::Utf8 => Expr::ScalarFunction(expr::ScalarFunction {
+            func_def: ScalarFunctionDefinition::UDF(Arc::new((*STR_TO_UTC_TIMESTAMP_UDF).clone())),
             args: vec![arg.clone(), lit(default_input_tz)],
         }),
         DataType::Null => arg.clone(),
         dtype if is_numeric_datatype(&dtype) || matches!(dtype, DataType::Boolean) => {
-            Expr::ScalarUDF(expr::ScalarUDF {
-                fun: Arc::new((*EPOCH_MS_TO_UTC_TIMESTAMP_UDF).clone()),
+            Expr::ScalarFunction(expr::ScalarFunction {
+                func_def: ScalarFunctionDefinition::UDF(Arc::new(
+                    (*EPOCH_MS_TO_UTC_TIMESTAMP_UDF).clone(),
+                )),
                 args: vec![cast_to(arg.clone(), &DataType::Int64, schema)?],
             })
         }
