@@ -1,5 +1,5 @@
 use crate::task_graph::timezone::RuntimeTzConfig;
-use datafusion_expr::{expr, lit, Expr, ExprSchemable};
+use datafusion_expr::{expr, lit, Expr, ExprSchemable, ScalarFunctionDefinition};
 use std::sync::Arc;
 use vegafusion_common::arrow::datatypes::DataType;
 use vegafusion_common::datafusion_common::DFSchema;
@@ -23,18 +23,24 @@ pub fn time_fn(tz_config: &RuntimeTzConfig, args: &[Expr], schema: &DFSchema) ->
     // Dispatch handling on data type
     let expr = match arg.get_type(schema)? {
         DataType::Timestamp(_, _) | DataType::Date32 | DataType::Date64 => {
-            Expr::ScalarUDF(expr::ScalarUDF {
-                fun: Arc::new((*UTC_TIMESTAMP_TO_EPOCH_MS).clone()),
+            Expr::ScalarFunction(expr::ScalarFunction {
+                func_def: ScalarFunctionDefinition::UDF(Arc::new(
+                    (*UTC_TIMESTAMP_TO_EPOCH_MS).clone(),
+                )),
                 args: vec![arg.clone()],
             })
         }
         DataType::Utf8 => {
             let mut udf_args = vec![lit(tz_config.default_input_tz.to_string())];
             udf_args.extend(Vec::from(args));
-            Expr::ScalarUDF(expr::ScalarUDF {
-                fun: Arc::new((*UTC_TIMESTAMP_TO_EPOCH_MS).clone()),
-                args: vec![Expr::ScalarUDF(expr::ScalarUDF {
-                    fun: Arc::new((*STR_TO_UTC_TIMESTAMP_UDF).clone()),
+            Expr::ScalarFunction(expr::ScalarFunction {
+                func_def: ScalarFunctionDefinition::UDF(Arc::new(
+                    (*UTC_TIMESTAMP_TO_EPOCH_MS).clone(),
+                )),
+                args: vec![Expr::ScalarFunction(expr::ScalarFunction {
+                    func_def: ScalarFunctionDefinition::UDF(Arc::new(
+                        (*STR_TO_UTC_TIMESTAMP_UDF).clone(),
+                    )),
                     args: vec![arg.clone(), lit(tz_config.default_input_tz.to_string())],
                 })],
             })
