@@ -41,8 +41,8 @@ pub fn compile_conditional(
 
     if let Expr::Case(case) = alternate_expr {
         // Flatten nested case statements
-        let mut when_then_expr = case.when_then_expr;
-        when_then_expr.extend(vec![(Box::new(test), Box::new(consequent_expr))]);
+        let mut when_then_expr = vec![(Box::new(test), Box::new(consequent_expr))];
+        when_then_expr.extend(case.when_then_expr);
         Ok(Expr::Case(Case {
             expr: None,
             when_then_expr,
