@@ -1,6 +1,6 @@
 use crate::expression::compiler::{compile, config::CompilationConfig};
 
-use datafusion_expr::{expr, Expr, ExprSchemable};
+use datafusion_expr::{expr, Expr, ExprSchemable, ScalarFunctionDefinition};
 use std::sync::Arc;
 use vegafusion_common::arrow::datatypes::DataType;
 use vegafusion_common::datafusion_common::DFSchema;
@@ -26,8 +26,8 @@ pub fn compile_object(
 
     let udf = make_object_constructor_udf(keys.as_slice(), value_types.as_slice());
 
-    Ok(Expr::ScalarUDF(expr::ScalarUDF {
-        fun: Arc::new(udf),
+    Ok(Expr::ScalarFunction(expr::ScalarFunction {
+        func_def: ScalarFunctionDefinition::UDF(Arc::new(udf)),
         args: values,
     }))
 }
