@@ -1,18 +1,17 @@
 use crate::expression::compiler::config::CompilationConfig;
 use crate::transform::TransformTrait;
 
-use datafusion_expr::{
-    avg, count, count_distinct, lit, max, min, sum, BuiltinScalarFunction, Expr, ExprSchemable,
-};
+use datafusion_expr::{avg, count, count_distinct, lit, max, min, sum, Expr};
 use std::collections::HashMap;
 
 use async_trait::async_trait;
+use datafusion_expr::expr::AggregateFunctionDefinition;
 use datafusion_expr::{aggregate_function, expr};
 use std::sync::Arc;
 use vegafusion_common::column::{flat_col, unescaped_col};
 use vegafusion_common::data::ORDER_COL;
 use vegafusion_common::datafusion_common::{DFSchema, ScalarValue};
-use vegafusion_common::datatypes::{cast_to, to_numeric};
+use vegafusion_common::datatypes::to_numeric;
 use vegafusion_common::error::ResultWithContext;
 use vegafusion_common::escape::unescape_field;
 use vegafusion_core::arrow::datatypes::DataType;
@@ -162,45 +161,47 @@ pub fn make_agg_expr_for_col_expr(
         AggregateOp::Mean | AggregateOp::Average => avg(numeric_column()?),
         AggregateOp::Min => min(column),
         AggregateOp::Max => max(column),
-        AggregateOp::Sum => {
-            let numeric_col = numeric_column()?;
-            let dtype = numeric_col.get_type(schema)?;
-            let zero = cast_to(lit(0), &dtype, schema)?;
-            Expr::ScalarFunction(expr::ScalarFunction {
-                fun: BuiltinScalarFunction::Coalesce,
-                args: vec![sum(numeric_col), zero],
-            })
-        }
+        AggregateOp::Sum => sum(numeric_column()?),
         AggregateOp::Median => Expr::AggregateFunction(expr::AggregateFunction {
-            fun: aggregate_function::AggregateFunction::Median,
+            func_def: AggregateFunctionDefinition::BuiltIn(
+                aggregate_function::AggregateFunction::Median,
+            ),
             distinct: false,
             args: vec![numeric_column()?],
             filter: None,
             order_by: None,
         }),
         AggregateOp::Variance => Expr::AggregateFunction(expr::AggregateFunction {
-            fun: aggregate_function::AggregateFunction::Variance,
+            func_def: AggregateFunctionDefinition::BuiltIn(
+                aggregate_function::AggregateFunction::Variance,
+            ),
             distinct: false,
             args: vec![numeric_column()?],
             filter: None,
             order_by: None,
         }),
         AggregateOp::Variancep => Expr::AggregateFunction(expr::AggregateFunction {
-            fun: aggregate_function::AggregateFunction::VariancePop,
+            func_def: AggregateFunctionDefinition::BuiltIn(
+                aggregate_function::AggregateFunction::VariancePop,
+            ),
             distinct: false,
             args: vec![numeric_column()?],
             filter: None,
             order_by: None,
         }),
         AggregateOp::Stdev => Expr::AggregateFunction(expr::AggregateFunction {
-            fun: aggregate_function::AggregateFunction::Stddev,
+            func_def: AggregateFunctionDefinition::BuiltIn(
+                aggregate_function::AggregateFunction::Stddev,
+            ),
             distinct: false,
             args: vec![numeric_column()?],
             filter: None,
             order_by: None,
         }),
         AggregateOp::Stdevp => Expr::AggregateFunction(expr::AggregateFunction {
-            fun: aggregate_function::AggregateFunction::StddevPop,
+            func_def: AggregateFunctionDefinition::BuiltIn(
+                aggregate_function::AggregateFunction::StddevPop,
+            ),
             distinct: false,
             args: vec![numeric_column()?],
             filter: None,
@@ -228,15 +229,17 @@ pub fn make_agg_expr_for_col_expr(
             });
             count_distinct(column) + max(missing)
         }
-        AggregateOp::Q1 => Expr::AggregateUDF(expr::AggregateUDF {
-            fun: Arc::new((*Q1_UDF).clone()),
+        AggregateOp::Q1 => Expr::AggregateFunction(expr::AggregateFunction {
+            func_def: AggregateFunctionDefinition::UDF(Arc::new((*Q1_UDF).clone())),
             args: vec![numeric_column()?],
+            distinct: false,
             filter: None,
             order_by: None,
         }),
-        AggregateOp::Q3 => Expr::AggregateUDF(expr::AggregateUDF {
-            fun: Arc::new((*Q3_UDF).clone()),
+        AggregateOp::Q3 => Expr::AggregateFunction(expr::AggregateFunction {
+            func_def: AggregateFunctionDefinition::UDF(Arc::new((*Q3_UDF).clone())),
             args: vec![numeric_column()?],
+            distinct: false,
             filter: None,
             order_by: None,
         }),
