@@ -108,7 +108,7 @@ mod test_custom_specs {
         case("custom/trellis_bar_histogram", 0.001, false),
         case("custom/interactive_average", 0.001, false),
         case("custom/histogram_responsive", 0.001, false),
-        case("custom/grouped_bar_chart_with_error_bars", 0.001, false),
+        case("custom/grouped_bar_chart_with_error_bars", 0.002, false),
         case("custom/one_dot_per_zipcode", 0.001, false),
         case("custom/ridgeline", 0.001, false),
         case("custom/binned_scatter", 0.001, false),
@@ -155,6 +155,8 @@ mod test_custom_specs {
         case("custom/local_timezone_with_dot", 0.001, true),
         case("custom/gh_455", 0.001, true),
         case("custom/gh_456", 0.001, true),
+        case("custom/facet_dots_sort_datum", 0.001, true),
+        case("custom/gh_463", 0.001, true),
     )]
     fn test_image_comparison(spec_name: &str, tolerance: f64, extract_inline_values: bool) {
         println!("spec_name: {spec_name}");
@@ -752,8 +754,8 @@ mod test_vegalite_specs {
         case("vegalite/point_no_axis_domain_grid", 0.001),
 
         // (random function is non-deterministic so use higher tolerance)
-        case("vegalite/point_offset_random", 0.3),
-        case("vegalite/point_ordinal_bin_offset_random", 0.3),
+        case("vegalite/point_offset_random", 0.8),
+        case("vegalite/point_ordinal_bin_offset_random", 0.8),
 
         case("vegalite/point_ordinal_color", 0.001),
         case("vegalite/point_overlap", 0.001),
