@@ -78,6 +78,8 @@ fn maybe_from_utc(ts_expr: SqlExpr, time_zone: &str) -> SqlExpr {
                     SqlValue::SingleQuotedString(time_zone.to_string()),
                 ))),
             ],
+            filter: None,
+            null_treatment: None,
             over: None,
             distinct: false,
             special: false,
@@ -101,6 +103,8 @@ fn maybe_to_utc(ts_expr: SqlExpr, time_zone: &str) -> SqlExpr {
                     SqlValue::SingleQuotedString(time_zone.to_string()),
                 ))),
             ],
+            filter: None,
+            null_treatment: None,
             over: None,
             distinct: false,
             special: false,
@@ -137,6 +141,8 @@ impl FunctionTransformer for DateAddTzBigQueryTransformer {
                     SqlValue::SingleQuotedString(time_zone.clone()),
                 ))),
             ],
+            filter: None,
+            null_treatment: None,
             over: None,
             distinct: false,
             special: false,
@@ -161,6 +167,8 @@ impl FunctionTransformer for DateAddTzBigQueryTransformer {
                     },
                 ))),
             ],
+            filter: None,
+            null_treatment: None,
             over: None,
             distinct: false,
             special: false,
@@ -178,6 +186,8 @@ impl FunctionTransformer for DateAddTzBigQueryTransformer {
                     SqlValue::SingleQuotedString(time_zone),
                 ))),
             ],
+            filter: None,
+            null_treatment: None,
             over: None,
             distinct: false,
             special: false,
@@ -260,6 +270,8 @@ impl FunctionTransformer for DateAddTzDatabricksTransformer {
                 ))),
                 SqlFunctionArg::Unnamed(SqlFunctionArgExpr::Expr(ts_in_tz_expr)),
             ],
+            filter: None,
+            null_treatment: None,
             over: None,
             distinct: false,
             special: false,
@@ -350,6 +362,8 @@ impl FunctionTransformer for DateAddTzSnowflakeTransformer {
                     ))),
                     SqlFunctionArg::Unnamed(SqlFunctionArgExpr::Expr(ts_expr)),
                 ],
+                filter: None,
+                null_treatment: None,
                 over: None,
                 distinct: false,
                 special: false,
@@ -372,6 +386,8 @@ impl FunctionTransformer for DateAddTzSnowflakeTransformer {
                 ))),
                 SqlFunctionArg::Unnamed(SqlFunctionArgExpr::Expr(timestamp_in_tz)),
             ],
+            filter: None,
+            null_treatment: None,
             over: None,
             distinct: false,
             special: false,
@@ -395,6 +411,8 @@ impl FunctionTransformer for DateAddTzSnowflakeTransformer {
                     ))),
                     SqlFunctionArg::Unnamed(SqlFunctionArgExpr::Expr(date_add_in_tz)),
                 ],
+                filter: None,
+                null_treatment: None,
                 over: None,
                 distinct: false,
                 special: false,
