@@ -104,6 +104,8 @@ impl FunctionTransformer for MakeUtcTimestampBigQueryTransformer {
                 SqlFunctionArg::Unnamed(SqlFunctionArgExpr::Expr(sql_args.month)),
                 SqlFunctionArg::Unnamed(SqlFunctionArgExpr::Expr(sql_args.day)),
             ],
+            filter: None,
+            null_treatment: None,
             over: None,
             distinct: false,
             special: false,
@@ -120,6 +122,8 @@ impl FunctionTransformer for MakeUtcTimestampBigQueryTransformer {
                 SqlFunctionArg::Unnamed(SqlFunctionArgExpr::Expr(sql_args.minute)),
                 SqlFunctionArg::Unnamed(SqlFunctionArgExpr::Expr(sql_args.second)),
             ],
+            filter: None,
+            null_treatment: None,
             over: None,
             distinct: false,
             special: false,
@@ -143,6 +147,8 @@ impl FunctionTransformer for MakeUtcTimestampBigQueryTransformer {
                     },
                 ))),
             ],
+            filter: None,
+            null_treatment: None,
             over: None,
             distinct: false,
             special: false,
@@ -158,6 +164,8 @@ impl FunctionTransformer for MakeUtcTimestampBigQueryTransformer {
                 SqlFunctionArg::Unnamed(SqlFunctionArgExpr::Expr(date_expr)),
                 SqlFunctionArg::Unnamed(SqlFunctionArgExpr::Expr(time_with_ms_expr)),
             ],
+            filter: None,
+            null_treatment: None,
             over: None,
             distinct: false,
             special: false,
@@ -175,6 +183,8 @@ impl FunctionTransformer for MakeUtcTimestampBigQueryTransformer {
                     SqlValue::SingleQuotedString(sql_args.time_zone),
                 ))),
             ],
+            filter: None,
+            null_treatment: None,
             over: None,
             distinct: false,
             special: false,
@@ -215,6 +225,8 @@ impl FunctionTransformer for MakeUtcTimestampDatabricksTransformer {
                 SqlFunctionArg::Unnamed(SqlFunctionArgExpr::Expr(sql_args.minute)),
                 SqlFunctionArg::Unnamed(SqlFunctionArgExpr::Expr(sql_args.second)),
             ],
+            filter: None,
+            null_treatment: None,
             over: None,
             distinct: false,
             special: false,
@@ -234,6 +246,8 @@ impl FunctionTransformer for MakeUtcTimestampDatabricksTransformer {
                 SqlFunctionArg::Unnamed(SqlFunctionArgExpr::Expr(sql_args.millisecond)),
                 SqlFunctionArg::Unnamed(SqlFunctionArgExpr::Expr(make_timestamp_expr)),
             ],
+            filter: None,
+            null_treatment: None,
             over: None,
             distinct: false,
             special: false,
@@ -254,6 +268,8 @@ impl FunctionTransformer for MakeUtcTimestampDatabricksTransformer {
                         SqlValue::SingleQuotedString(sql_args.time_zone),
                     ))),
                 ],
+                filter: None,
+                null_treatment: None,
                 over: None,
                 distinct: false,
                 special: false,
@@ -295,6 +311,8 @@ impl FunctionTransformer for MakeUtcTimestampDuckDbTransformer {
                 SqlFunctionArg::Unnamed(SqlFunctionArgExpr::Expr(sql_args.minute)),
                 SqlFunctionArg::Unnamed(SqlFunctionArgExpr::Expr(sql_args.second)),
             ],
+            filter: None,
+            null_treatment: None,
             over: None,
             distinct: false,
             special: false,
@@ -348,6 +366,8 @@ impl FunctionTransformer for MakeUtcTimestampPostgresTransformer {
                     SqlValue::SingleQuotedString(sql_args.time_zone),
                 ))),
             ],
+            filter: None,
+            null_treatment: None,
             over: None,
             distinct: false,
             special: false,
@@ -402,6 +422,8 @@ impl FunctionTransformer for MakeUtcTimestampSnowflakeTransformer {
                     ))),
                 })),
             ],
+            filter: None,
+            null_treatment: None,
             over: None,
             distinct: false,
             special: false,
@@ -425,6 +447,8 @@ impl FunctionTransformer for MakeUtcTimestampSnowflakeTransformer {
                     ))),
                     SqlFunctionArg::Unnamed(SqlFunctionArgExpr::Expr(make_timestamp_expr)),
                 ],
+                filter: None,
+                null_treatment: None,
                 over: None,
                 distinct: false,
                 special: false,
