@@ -46,6 +46,8 @@ impl FunctionTransformer for UtcTimestampToEpochMsDatabricksTransform {
             args: vec![SqlFunctionArg::Unnamed(SqlFunctionArgExpr::Expr(
                 ts_expr.clone(),
             ))],
+            filter: None,
+            null_treatment: None,
             over: None,
             distinct: false,
             special: false,
@@ -68,6 +70,8 @@ impl FunctionTransformer for UtcTimestampToEpochMsDatabricksTransform {
                 ))),
                 SqlFunctionArg::Unnamed(SqlFunctionArgExpr::Expr(ts_expr)),
             ],
+            filter: None,
+            null_treatment: None,
             over: None,
             distinct: false,
             special: false,
@@ -116,6 +120,8 @@ impl FunctionTransformer for UtcTimestampToEpochMsDuckdbTransform {
             args: vec![SqlFunctionArg::Unnamed(SqlFunctionArgExpr::Expr(
                 ts_expr.clone(),
             ))],
+            filter: None,
+            null_treatment: None,
             over: None,
             distinct: false,
             special: false,
@@ -138,6 +144,8 @@ impl FunctionTransformer for UtcTimestampToEpochMsDuckdbTransform {
                 ))),
                 SqlFunctionArg::Unnamed(SqlFunctionArgExpr::Expr(ts_expr)),
             ],
+            filter: None,
+            null_treatment: None,
             over: None,
             distinct: false,
             special: false,
@@ -189,6 +197,8 @@ impl FunctionTransformer for UtcTimestampToEpochMsPostgresTransform {
                     right: Box::new(SqlExpr::Value(SqlValue::Number("1000".to_string(), false))),
                 },
             ))],
+            filter: None,
+            null_treatment: None,
             over: None,
             distinct: false,
             special: false,
@@ -226,6 +236,8 @@ impl FunctionTransformer for UtcTimestampToEpochMsSnowflakeTransform {
                 }))),
                 SqlFunctionArg::Unnamed(SqlFunctionArgExpr::Expr(ts_expr)),
             ],
+            filter: None,
+            null_treatment: None,
             over: None,
             distinct: false,
             special: false,
